#!/bin/sh
# wdimex.sh -- make anmess.wdm for annie
#              build test wdm file for graph tests
#
# History:  95/12/08 kmflynn
#           97/02/06 kmflynn add test.wdm option
#           00/04/04 kmflynn
#
# Usage: wdimex.sh [ file_name ] [| tee output_file ]
#
# Where: file_name = the name of the message file or test wdm file to build
#                    anmess - to generate the annie message file (default)
#                      test - to generate the wdm file used by graphics test
#                      both - generate both message and test wdm files
#
# Examples:  wdimex.sh
#            wdimex.sh test

# pathnames and directories
  WrdA=/usr/opt/wrdapp
  Libr=$WrdA/libanne4.0

#*******************************************************************
#***** You should not need to modify anything below this line. *****
#*******************************************************************

Optn=${1-'anmess'}
     if [ ! $Optn ] ; then Optn=anmess ; fi

# files for message file
  SeqMsg='annie'
  SeqLib='ann/atwork    ann/atdisp    ann/dswork    ann/dsbld     ann/qtdate
          ann/prwarc    ann/wdplot    ann/tswork    ann/pgener    ann/qtprnt
          waide/agplot  waide/tbltmp  waide/tslist  waide/tstabl'
# files for test wdm file
  SeqDat='../data/cane.exp ../data/il.exp'

  echo
  echo ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ; echo
  echo '     building wdm file(s) for:' $Optn                       ; echo
  echo '              Library =' $Libr
  echo

  if [ $Optn = 'anmess'  -o  $Optn = 'both' ] ; then
#    build the message file
     Name=anmess
     echo ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ; echo
     echo '             wdm name =' $Name.wdm
     echo '          sequentials =' $SeqMsg
     for Seq in $SeqLib ; do
     echo '                       ' $Seq
     done
     echo
     echo ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ; echo

#    remove any old files
     if [ -f error.fil ] ; then rm error.fil ; fi
     if [ -f $Name.wdm ] ; then rm $Name.wdm ; fi
     if [ -f $Name.in  ] ; then rm $Name.in  ; fi
     if [ -f $Name.err ] ; then rm $Name.err ; fi

#    build input file
     echo $Name.wdm > $Name.in
     for Seq in $SeqMsg ; do
        echo I >> $Name.in
        echo $Seq.seq >> $Name.in
     done
     for Seq in $SeqLib ; do
        echo I >> $Name.in
        echo $Libr/msg/$Seq.seq >> $Name.in
     done
     echo R >> $Name.in

#    get message file shell
     cp $Libr/lib_data/message.wdm $Name.wdm

#    build message file
     $Libr/bin/wdimex < $Name.in

#    remove old message file and move new one
     if [ -f ../bin_data/$Name.wdm ] ; then rm ../bin_data/$Name.wdm ; fi
     mv $Name.wdm ../bin_data
     mv error.fil $Name.err
  fi

  if [ $Optn = 'test'  -o  $Optn = 'both' ] ; then
#    build the test wdm file
     Name=test
     echo ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ; echo
     echo '             wdm name =' $Name.wdm
     echo '          sequentials =' $SeqDat
     echo
     echo ' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ' ; echo

#    remove any old files
     if [ -f error.fil ] ; then rm error.fil ; fi
     if [ -f $Name.wdm ] ; then rm $Name.wdm ; fi
     if [ -f $Name.in ]  ; then rm $Name.in  ; fi
     if [ -f $Name.err ] ; then rm $Name.err ; fi

#    build input file
     echo $Name.wdm > $Name.in
     echo C >> $Name.in
     echo N >> $Name.in
     echo $Libr/lib_data/message.wdm >> $Name.in
     for Seq in $SeqDat ; do
        echo I >> $Name.in
        echo $Seq >> $Name.in
     done
     echo R >> $Name.in

#    build test wdm file
     $Libr/bin/wdimex < $Name.in

#    remove old test wdm file and move new one into data
     if [ -f ../data/$Name.wdm ] ; then rm ../data/$Name.wdm ; fi
     mv $Name.wdm ../data/$Name.wdm
#    save error file
     echo > $Name.err
     echo ' NOTICE:  Data is imported from 2 files.'     >> $Name.err
     echo '          The first file conains dsn 5-11,'   >> $Name.err
     echo '          and each dsn contains both'         >> $Name.err
     echo '          attributes and time-series data.'   >> $Name.err
     echo '          The second file contains dsn 16-46' >> $Name.err
     echo '          and each dsn contains attributes'   >> $Name.err
     echo '          but no time-series data.'           >> $Name.err
     echo  >> $Name.err
     cat error.fil >> $Name.err
     rm error.fil
  fi

# end of shell
