#!/bin/sh
#
#    check.sh:  Compare (using diff) 'original' versions of files to
#               files in current directory.  Used most often to compare
#               expected files to actual test output.
#   arguments:  DirO - directory containing original, expected versions
#                      defaults to ../data
#               Name - prefix of file names, defaults to both
#                       test - non-graphics tests
#                      graph - graphics tests
#                       both - both test and graph
#  file names:  naming convention is "nameN.sfx", where:
#               name - prefix of file name, see Names below
#                  N - test numbers, see Tests below
#                sfx - suffix for file names, see Sufx below
#
#     history:  96/04/17 kmflynn  modified version of check.sh

  DirO=${1-../data}             # by default, data in parallel directory
  Name=${2-both}                # by default, file prefix is both

# output file for differences
  checkout='check.log'
# define range of tests and sufixes to be considered
  Tests='1 2 3 4 5 6'
  Sufix='out ot1 ot2 exp err ps'
  if [ $Name = 'both' -o $Name = 'BOTH' ] ; then
     Names='test graph'
  else
     Names=$Name
  fi

# delete old file and write heading to file
  if [ -f $checkout ] ; then rm $checkout ; fi
  echo                                                        | tee $checkout
  echo                                                        | tee -a $checkout
  echo                                                        | tee -a $checkout
  echo "Comparing original output files and new output files" | tee -a $checkout
  echo "Original files in: " $DirO                            | tee -a $checkout
  echo "             date: " `date`                           | tee -a $checkout
  echo "  "                                                   | tee -a $checkout
  echo                                                        | tee -a $checkout
  echo " Note:  In checking the compare differences, you"     | tee -a $checkout
  echo "        should expect to see differences in the"      | tee -a $checkout
  echo "        files for the run date and time"              | tee -a $checkout
  echo                                                        | tee -a $checkout
  echo "        In .exp files, the attributes DATCRE and"     | tee -a $checkout
  echo "        DATMOD may be different.  In .ps files,"      | tee -a $checkout
  echo "        the Creation Date will be different."         | tee -a $checkout
  echo                                                        | tee -a $checkout
  echo " Note:  If the graph tests use the test.wdm file"     | tee -a $checkout
  echo "        generated by the test tests, the .err files"  | tee -a $checkout
  echo "        should be identical.  If the test.wdm file"   | tee -a $checkout
  echo "        from the data directory is used, the dsns"    | tee -a $checkout
  echo "        expected will differ (38 rather than 41)"     | tee -a $checkout
  echo "        and the lines for 3 good data sets will"      | tee -a $checkout
  echo "        not be included."                             | tee -a $checkout
  echo                                                        | tee -a $checkout

  for Name in $Names ; do
     for Test in $Tests ; do
        for Sufx in $Sufix ; do
           if [ -f $DirO/$Name$Test.$Sufx -a -f $Name$Test.$Sufx ] ; then
              # both original and new output files exist, compare
              echo "_________________________________________________________ " \
                   $Name$Test.$Sufx | tee -a $checkout
              if diff $DirO/$Name$Test.$Sufx $Name$Test.$Sufx >> $checkout
                 then
                 echo FILES ARE IDENTICAL | tee -a $checkout
              else
                 echo FILES DIFFER:  see file $checkout for differences
              fi
           fi
        done
     done
  done

# end of shell
