#!/bin/sh
# graph.sh -- run annie graphics tests
#
# Usage: graph.sh [start [stop]]
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# History: 95/08/21  kmflynn
#          98/03/06  kmflynn
#          98/06/29  kmflynn

# pathnames
WrdA=/usr/opt/wrdapp
Anne=$WrdA/annie4.1

#*******************************************************************
#*****   Some things may need to be changed below this line.   *****
#*******************************************************************

# version of gks being used, set Gks as appropriate
#    Xgks - if using Xgks library from Unidata
#    PriorGks - if using Prior Gks library from Computer Assoc.
#    GliGks - is using Gli/Gks
# for a value of 'x' - tests will produce screen graphs, only
#                ' ' - tests will also produce PostScript and Cgm
    XGks=x
PriorGks=
  GliGks=
#
     Gks=$GliGks           # gks version (GliGks, XGks, or PriorGks)

#*******************************************************************
#***** You should not need to modify anything below this line. *****
#*******************************************************************

  Data=$Anne/data
  Chck=$Anne/test

  exec 2>&1                          # stderr shows up in .out file

  Start=${1-1}                       # by default, start at 1
  Stop=${2-6}                        # by default, stop at 6
                                     # 0 - annie, import wdm file
                                     # 1 - hydrograph, 3 axes
                                     # 2 - hydrograph, 2 axes
                                     # 3 - x-y plot
                                     # 4 - x-y plot
                                     # 5 - atribute plot, p100 vs darea
                                     # 6 - attribute, p100 & p1.25 vs darea
#
# begin test runs
  if [ -f graph.out ] ; then rm graph.out ; fi
  echo                                                        | tee    graph.out
  echo ______________________________________________________ | tee -a graph.out
  echo                                                        | tee -a graph.out
  echo " `date` "                                             | tee -a graph.out
  echo                                                        | tee -a graph.out
  echo " Processing annie graphics test runs $Start to $Stop" | tee -a graph.out
  echo                                                        | tee -a graph.out
  echo "  annie program from: $Anne"                          | tee -a graph.out
  echo "      test data from: $Data"                          | tee -a graph.out

  Test=$Start

  if [ $Test -eq 0  -o  ! -f test.wdm ] ; then
#    copy wdm file from data or build a new one
     echo                                                     | tee -a graph.out
     echo                                                     | tee -a graph.out
     echo ___________________________________________________ | tee -a graph.out
     echo "Test run number $Test - new wdm file"              | tee -a graph.out
     echo                                                     | tee -a graph.out
#    delete old if looking for a new one
     if [ $Test -eq 0 ] ; then rm test.wdm ; fi
     if [ -f $Data/test.wdm ] ; then
#       copy wdm from data directory
        echo " Copying the test.wdm file from $Data"             | tee -a graph.out
        cp -p $Data/test.wdm test.wdm
     else
#       create WDM file from export files
        echo " Building the test.wdm file using annie"           | tee -a graph.out
#       remove old output files
        for File in ERROR.FIL ANNIE.LOG graph0.err test.wdm ; do
           if [ -f $File ] ; then rm $File ; fi
        done
#       update links to input files
        for File in cane.exp il.exp ; do
           if [ -f $File ] ; then rm $File ; fi
           ln -s $Data/$File $File
        done
        $Anne/bin/annie <<-EOT
	@$Data/test1.log
	EOT
#       save error file
        mv ERROR.FIL graph0.err
#       remove unneeded files
        for File in cane.exp il.exp ANNIE.LOG; do
           if [ -f $File ] ; then rm $File ; fi
        done
     fi
     if [ $Test -eq 0 ] ; then Test=`expr $Test + 1` ; fi
  else
     echo " Using the test.wdm that is in the directory"      | tee -a graph.out
  fi

  while [ $Test -ge $Start -a $Test -le $Stop ] ; do
#    annie graphics test runs
     echo                                                     | tee -a graph.out
     echo                                                     | tee -a graph.out
     echo ___________________________________________________ | tee -a graph.out
     echo "Test run number $Test"                             | tee -a graph.out
     echo                                                     | tee -a graph.out
     for Fils in ANNIE.LOG ERROR.FIL graph$Gks$Test.ps ; do
#       remove old files
        if [ -f $Fils ] ; then rm $Fils ; fi
     done

     $Anne/bin/annie <<-EOT
	@$Data/graph$Gks$Test.log
	EOT

#    save error file
     mv ERROR.FIL graph$Gks$Test.err

#    remove unneeded files
     rm ANNIE.LOG
     rm XPAD.DAT

     Test=`expr $Test + 1`
  done

  echo                                                        | tee -a graph.out
  echo                                                        | tee -a graph.out
  echo ______________________________________________________ | tee -a graph.out
  echo "Completed ANNIE graphics test runs $Start to $Stop"   | tee -a graph.out
  echo                                                        | tee -a graph.out
# check output against original output in $Data directory
  $Chck/check.sh $Data
# $Chck/check.sh $Data graph$Gks

# end of shell
