#!/bin/sh
# test.sh -- run annie test data sets
#
# Usage: test.sh [start [stop]]
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# History: 96/04/17  kmflynn
#          98/03/06  kmflynn
#          98/06/29  kmflynn
#          00/04/04  kmflynn

# pathnames
  WrdA=/usr/opt/wrdapp
  Anne=$WrdA/annie4.1

#*******************************************************************
#***** You should not need to modify anything below this line. *****
#*******************************************************************

  Data=$Anne/data
  Chck=$Anne/test

  exec 2>&1                          # stderr shows up in .out file
  Start=${1-1}                       # by default, start at 1
  Stop=${2-5}                        # by default, stop at 5
                                     # 1 - create wdm, import data
                                     # 2 - table attributes
                                     # 3 - generate and archive
                                     # 4 - test archive range
                                     # 5 - list & table time series
#
# begin test runs
  if [ -f test.out ] ; then rm test.out ; fi
  echo                                                        | tee    test.out
  echo ______________________________________________________ | tee -a test.out
  echo                                                        | tee -a test.out
  echo " `date` "                                             | tee -a test.out
  echo                                                        | tee -a test.out
  echo " Processing annie test runs $Start to $Stop"          | tee -a test.out
  echo                                                        | tee -a test.out
  echo " annie program from: $Anne"                           | tee -a test.out
  echo "     test data from: $Data"                           | tee -a test.out
  echo                                                        | tee -a test.out

  if [ $Start -eq 1 ] ; then
#    remove old files
     if [ -f test.wdm ] ; then rm test.wdm ; fi
     if [ -f cane.exp ] ; then rm cane.exp ; fi
     if [ -f il.exp ]   ; then rm il.exp   ; fi
#    link in input files
     ln -s $Data/cane.exp cane.exp
     ln -s $Data/il.exp il.exp
  fi

  Test=$Start
  while [ $Test -ge $Start -a $Test -le $Stop ] ; do
#    each requested test run
     echo                                                     | tee -a test.out
     echo                                                     | tee -a test.out
     echo ___________________________________________________ | tee -a test.out
     echo "Test run number $Test"                             | tee -a test.out
     echo                                                     | tee -a test.out
     for File in ANNIE.LOG ERROR.FIL test$Test.out test$Test.ot1 test$Test.ot2  test$Test.exp ; do
#       remove old files
        if [ -f $File ] ; then rm $File ; fi
     done

     if [ $Test -eq 4 ] ; then
#      remove old file, link in input file
       if [ -f test$Test.imp ] ; then rm test$Test.imp ; fi
       ln -s $Data/test$Test.imp test$Test.imp
     fi

     $Anne/bin/annie <<-EOT
	@$Data/test$Test.log
	EOT

#    save error file, remove unneeded files
     mv ERROR.FIL test$Test.err
     rm ANNIE.LOG
     rm XPAD.DAT

     Test=`expr $Test + 1`
  done
#
# remove any linked files
  for Fils in cane.exp il.exp test4.imp ; do
     if [ -f $Fils ] ; then rm $Fils ; fi
  done

  echo                                                        | tee -a test.out
  echo                                                        | tee -a test.out
  echo ______________________________________________________ | tee -a test.out
  echo "Completed ANNIE test runs $Start to $Stop"            | tee -a test.out
  echo                                                        | tee -a test.out
# check output against original output in $Data directory
  $Chck/check.sh $Data

# end of shell
